# coding: utf-8

"""
    Workspace Data Service

    This page lists current APIs.  All v0.2 APIs are subject to change without notice.  Changelog at [https://github.com/DataBiosphere/terra-workspace-data-service/releases](https://github.com/DataBiosphere/terra-workspace-data-service/releases) 

    The version of the OpenAPI document: v0.2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wds_client.api.schema_api import SchemaApi


class TestSchemaApi(unittest.TestCase):
    """SchemaApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SchemaApi()

    def tearDown(self) -> None:
        pass

    def test_delete_attribute(self) -> None:
        """Test case for delete_attribute

        Delete attribute from record type
        """
        pass

    def test_delete_record_type(self) -> None:
        """Test case for delete_record_type

        Delete record type
        """
        pass

    def test_describe_all_record_types(self) -> None:
        """Test case for describe_all_record_types

        Describe all record types
        """
        pass

    def test_describe_record_type(self) -> None:
        """Test case for describe_record_type

        Describe record type
        """
        pass

    def test_update_attribute(self) -> None:
        """Test case for update_attribute

        Update an attribute
        """
        pass


if __name__ == '__main__':
    unittest.main()
