# coding: utf-8

"""
    Workspace Data Service

    This page lists current APIs.  All v0.2 APIs are subject to change without notice.  Changelog at [https://github.com/DataBiosphere/terra-workspace-data-service/releases](https://github.com/DataBiosphere/terra-workspace-data-service/releases) 

    The version of the OpenAPI document: v0.2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wds_client.api.records_api import RecordsApi


class TestRecordsApi(unittest.TestCase):
    """RecordsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = RecordsApi()

    def tearDown(self) -> None:
        pass

    def test_batch_write_records(self) -> None:
        """Test case for batch_write_records

        Batch write records
        """
        pass

    def test_create_or_replace_record(self) -> None:
        """Test case for create_or_replace_record

        Create or replace record
        """
        pass

    def test_delete_record(self) -> None:
        """Test case for delete_record

        Delete record
        """
        pass

    def test_get_record(self) -> None:
        """Test case for get_record

        Get record
        """
        pass

    def test_get_records_as_tsv(self) -> None:
        """Test case for get_records_as_tsv

        Retrieve all records in record type as tsv.
        """
        pass

    def test_query_records(self) -> None:
        """Test case for query_records

        Query records
        """
        pass

    def test_update_record(self) -> None:
        """Test case for update_record

        Update record
        """
        pass

    def test_upload_tsv(self) -> None:
        """Test case for upload_tsv

        Import records to a record type from a tsv file
        """
        pass


if __name__ == '__main__':
    unittest.main()
