# coding: utf-8

"""
    Workspace Data Service

    This page lists current APIs.  All v0.2 APIs are subject to change without notice.  Changelog at [https://github.com/DataBiosphere/terra-workspace-data-service/releases](https://github.com/DataBiosphere/terra-workspace-data-service/releases) 

    The version of the OpenAPI document: v0.2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wds_client.api.workspace_api import WorkspaceApi


class TestWorkspaceApi(unittest.TestCase):
    """WorkspaceApi unit test stubs"""

    def setUp(self) -> None:
        self.api = WorkspaceApi()

    def tearDown(self) -> None:
        pass

    def test_init_workspace_v1(self) -> None:
        """Test case for init_workspace_v1

        Initialize WDS for a given workspace.
        """
        pass


if __name__ == '__main__':
    unittest.main()
